==> contentsquare-3.5.1.tar.gz: android/src/main/kotlin/com/contentsquare/flutter/infrastructure/core/method_call_executor/agents/MethodCallAgent.kt <==
package com.contentsquare.flutter.infrastructure.core.method_call_executor.agents

import com.contentsquare.flutter.infrastructure.core.method_call_executor.data.ExecutionData
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.ExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponseReason
import io.flutter.plugin.common.MethodCall
import kotlin.reflect.KClass


/**
 * Agent used to execute specific method from [MethodCall].
 */
internal abstract class MethodCallAgent(private val nativeExceptionMessage: String?) {
    /**
     * Process the execution of the method
     *
     * @param data Data used during execution
     */
    protected abstract fun execute(data: ExecutionData): ExecutionResponse

    /**
     * Process the execution of the method and catch any error/exception.
     *
     * @param data Data used during execution
     */
    fun safeExecute(data: ExecutionData): ExecutionResponse {
        return try {
            execute(data)
        } catch (t: Throwable) {
            FailedExecutionResponse(
                FailedExecutionResponseReason.NATIVE_EXCEPTION,
                nativeExceptionMessage,
                t
            )
        }
    }

    companion object Factory {
        /**
         * Creates a new instance implementation of [MethodCallAgent].
         *
         * @param method the method to execute used to create the specific [MethodCallAgent]
         */
        fun of(method: String): MethodCallAgent {
            val agentMethod = AgentMethod.values().firstOrNull { agentMethod ->
                agentMethod.method == method
            }
            if (agentMethod == null || agentMethod == AgentMethod.UNKNOWN) {
                return MissingMethodCallAgent(method = method)
            }

            return agentMethod.agentClass.java.newInstance()
        }
    }
}


internal enum class AgentMethod(val method: String, val agentClass: KClass<out MethodCallAgent>) {
    UNKNOWN(method = "__unknown_method__", agentClass = MissingMethodCallAgent::class),
    STOP_TRACKING(method = "stopTracking", agentClass = StopTrackingAgent::class),
    SET_URL_MASKING_PATTERNS(method = "setURLMaskingPatterns", agentClass = SetURLMaskingPatternsAgent::class),
    SEND_TRANSACTION(method = "sendTransaction", agentClass = SendTransactionAgent::class),
    SEND_TOUCH_EVENT(method = "sendTouchEvent", agentClass = SendTouchEventAgent::class),
    SEND_SESSION_REPLAY_EVENT(method = "sendSessionReplayEvent", agentClass = SendSessionReplayEventAgent::class),
    SEND_SCREEN_NAME(method = "send", agentClass = SendScreenNameAgent::class),
    SEND_DYNAMIC_VAR(method = "sendDynamicVar", agentClass = SendDynamicVarAgent::class),
    SEND_API_ERROR(method = "sendApiError", agentClass = SendApiErrorAgent::class),
    RESUME_TRACKING(method = "resumeTracking", agentClass = ResumeTrackingAgent::class),
    GET_USER_ID(method = "getUserId", agentClass = GetUserIdAgent::class),
    GET_CURRENT_SESSION_REPLAY_URL(method = "currentSessionReplayUrl", agentClass = GetCurrentSessionReplayLinkAgent::class),
    FORGET_ME(method = "forgetMe", agentClass = ForgetMeAgent::class),
    OPT_OUT(method = "optOut", agentClass = OptOutAgent::class),
    OPT_IN(method = "optIn", agentClass = OptInAgent::class),
    COLLECT_FLUTTER_VERSION(method = "collectFlutterVersion", agentClass = CollectFlutterVersionAgent::class),
    COLLECT_CUSTOM_TELEMETRY_DATA(method = "collectCustomTelemetryData", agentClass = CollectCustomTelemetryAgent::class),
    SEND_USER_IDENTIFIER(method = "sendUserIdentifier", agentClass = SendUserIdentifierAgent::class),
    GET_STORED_CONFIG(method = "getInitialConfig", agentClass = GetStoredConfigAgent::class)
}

==> contentsquare-3.7.0.tar.gz: android/src/main/kotlin/com/contentsquare/flutter/infrastructure/core/method_call_executor/agents/MethodCallAgent.kt <==
package com.contentsquare.flutter.infrastructure.core.method_call_executor.agents

import com.contentsquare.flutter.infrastructure.core.method_call_executor.data.ExecutionData
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.ExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponseReason
import io.flutter.plugin.common.MethodCall
import kotlin.reflect.KClass


/**
 * Agent used to execute specific method from [MethodCall].
 */
internal abstract class MethodCallAgent(private val nativeExceptionMessage: String?) {
    /**
     * Process the execution of the method
     *
     * @param data Data used during execution
     */
    protected abstract fun execute(data: ExecutionData): ExecutionResponse

    /**
     * Process the execution of the method and catch any error/exception.
     *
     * @param data Data used during execution
     */
    fun safeExecute(data: ExecutionData): ExecutionResponse {
        return try {
            execute(data)
        } catch (t: Throwable) {
            FailedExecutionResponse(
                FailedExecutionResponseReason.NATIVE_EXCEPTION,
                nativeExceptionMessage,
                t
            )
        }
    }

    companion object Factory {
        /**
         * Creates a new instance implementation of [MethodCallAgent].
         *
         * @param method the method to execute used to create the specific [MethodCallAgent]
         */
        fun of(method: String): MethodCallAgent {
            val agentMethod = AgentMethod.values().firstOrNull { agentMethod ->
                agentMethod.method == method
            }
            if (agentMethod == null || agentMethod == AgentMethod.UNKNOWN) {
                return MissingMethodCallAgent(method = method)
            }

            return agentMethod.agentClass.java.newInstance()
        }
    }
}


internal enum class AgentMethod(val method: String, val agentClass: KClass<out MethodCallAgent>) {
    UNKNOWN(method = "__unknown_method__", agentClass = MissingMethodCallAgent::class),
    STOP_TRACKING(method = "stopTracking", agentClass = StopTrackingAgent::class),
    SET_URL_MASKING_PATTERNS(method = "setURLMaskingPatterns", agentClass = SetURLMaskingPatternsAgent::class),
    SEND_TRANSACTION(method = "sendTransaction", agentClass = SendTransactionAgent::class),
    SEND_TOUCH_EVENT(method = "sendTouchEvent", agentClass = SendTouchEventAgent::class),
    SEND_SESSION_REPLAY_EVENT(method = "sendSessionReplayEvent", agentClass = SendSessionReplayEventAgent::class),
    SEND_SCREEN_NAME(method = "send", agentClass = SendScreenNameAgent::class),
    SEND_DYNAMIC_VAR(method = "sendDynamicVar", agentClass = SendDynamicVarAgent::class),
    SEND_API_ERROR(method = "sendApiError", agentClass = SendApiErrorAgent::class),
    RESUME_TRACKING(method = "resumeTracking", agentClass = ResumeTrackingAgent::class),
    GET_USER_ID(method = "getUserId", agentClass = GetUserIdAgent::class),
    GET_CURRENT_SESSION_REPLAY_URL(method = "currentSessionReplayUrl", agentClass = GetCurrentSessionReplayLinkAgent::class),
    FORGET_ME(method = "forgetMe", agentClass = ForgetMeAgent::class),
    OPT_OUT(method = "optOut", agentClass = OptOutAgent::class),
    OPT_IN(method = "optIn", agentClass = OptInAgent::class),
    COLLECT_XPF_VERSION(method = "collectXPFVersion", agentClass = CollectXPFVersionAgent::class),
    COLLECT_CUSTOM_TELEMETRY_DATA(method = "collectCustomTelemetryData", agentClass = CollectCustomTelemetryAgent::class),
    SEND_USER_IDENTIFIER(method = "sendUserIdentifier", agentClass = SendUserIdentifierAgent::class),
    GET_STORED_CONFIG(method = "getInitialConfig", agentClass = GetStoredConfigAgent::class)
}
